from Anar import Lagrange
from Anar import brent
from Anar import golden_ratio
from Anar import parse_variables_tz2
from Anar import parabolic_interpolation
from Anar import plot
from Anar import gradient_descent_fixed
from Anar import local_extrema
from Anar import gradient_descent_fixed
from Anar import parse__restr_function
from Anar import parse_restriction
from Anar import parse_variables
from Anar import parser_task
from Anar import tz4
from Anar import plot
from Anar import plot_tz2


